==> cf_2.26.1.orig.tar.gz: cf-2.26.1/connectors/cf-zserver-regression/regression.sh <==
#!/bin/sh
# assumes pwd is engine/src, and that MP has been started.


DIR=`dirname $0`            # ../../connectors/cf-zserver-regression
PLAINDIR=`basename $DIR`    # cf-zserver-regression

GRET=0
: ${diff_opt="-u"}
: ${REGRESSION_FATAL=false}

if [ $1 ]
then
  echo "running $0, only for $1"
  CONNECTORLIST=$1
else
  echo "running $0"
  CONNECTORLIST=`cd $DIR/..; ls *.cf $PLAINDIR/*.cf`
fi

for C in $CONNECTORLIST
do
    CNAME=`basename $C .cf`
    CDIR=`dirname $C`
    if [ $CDIR = "." ]
    then
      CONNECTOR=$CNAME
    else
      CONNECTOR=$CDIR/$CNAME
    fi

    RET=0
    QRYFILE=$DIR/$CNAME.query
    LOG=$DIR/$CNAME.mp.log
    rm -f $LOG
    if test -f $QRYFILE; then
      while read QRY1
      do  # for each line in the file
        echo "======================" >> $LOG
        # If line starts with '?', take first word to be dbname params
        # and the rest to be the query. Pass the params with the connector name.
        echo $QRY1  >> $LOG
        QRY2=`echo $QRY1 | sed 's/^#.*$//' `  # strip comment lines
        QRY=`echo $QRY2 | sed 's/^\?[^ ]* *//'`  # remove the params
        DBPARM=`echo $QRY2 | sed -r 's/(\?[^ ]*)?( ?.*)/\1/'` # keep just the db
        #echo "DB='$DBPARM'" >> $LOG   # ###
        #echo "Q='$QRY'" >> $LOG       # ###
        #echo "C-DB='$CONNECTOR$DBPARM'" >> $LOG # ###
        if [ ! -z "$QRY" ]
        then
          zoomsh "connect localhost:9070" "set databaseName $CONNECTOR$DBPARM" \
                  "set count 2" "search $QRY" "quit" >>$LOG
          test $? -ne 0 && RET=1
        fi
      done < $QRYFILE
    fi
    I=$DIR/$CNAME.input
    if test -f $I; then
        echo "===== $I ======" >> $LOG
	echo "connect localhost:9070" >input.tmp
	echo "set databaseName $CONNECTOR$DBPARM" >>input.tmp
	cat $I >>input.tmp
	echo "quit" >>input.tmp
	zoomsh < input.tmp | sed 's/ZOOM>//g' >>$LOG
        test $? -ne 0 && RET=1
	rm -f input.tmp
    fi
    if test -f $DIR/$CNAME.out; then
	diff $diff_opt $DIR/$CNAME.out $LOG
	if test $? -ne 0; then
	    echo "  $CNAME: differ (MP)"
            GRET=1
	else
	    echo "  $CNAME: OK (MP)"
	fi
    else
        echo "   $CNAME: Making for the first time"
        cp $LOG $DIR/$CNAME.out
    fi

done # connector loop

exit $GRET

==> cf_2.27.2.orig.tar.gz: cf-2.27.2/connectors/cf-zserver-regression/regression.sh <==
#!/bin/sh
# assumes pwd is engine/src, and that MP has been started.


DIR=`dirname $0`            # ../../connectors/cf-zserver-regression
PLAINDIR=`basename $DIR`    # cf-zserver-regression

GRET=0
: ${diff_opt="-u"}
: ${REGRESSION_FATAL=false}

checkresult=true
if test "$1" = "runonly"; then
  checkresult=false
  CONNECTORLIST=`cd $DIR/..; ls *.cf $PLAINDIR/*.cf`
elif test -n "$1" ; then
  echo "running $0, only for $1"
  CONNECTORLIST=$1
else
  echo "running $0"
  CONNECTORLIST=`cd $DIR/..; ls *.cf $PLAINDIR/*.cf`
fi

for C in $CONNECTORLIST
do
    CNAME=`basename $C .cf`
    CDIR=`dirname $C`
    if [ $CDIR = "." ]
    then
      CONNECTOR=$CNAME
    else
      CONNECTOR=$CDIR/$CNAME
    fi

    RET=0
    QRYFILE=$DIR/$CNAME.query
    LOG=$DIR/$CNAME.mp.log
    rm -f $LOG
    if test -f $QRYFILE; then
      while read QRY1
      do  # for each line in the file
        echo "======================" >> $LOG
        # If line starts with '?', take first word to be dbname params
        # and the rest to be the query. Pass the params with the connector name.
        echo $QRY1  >> $LOG
        QRY2=`echo $QRY1 | sed 's/^#.*$//' `  # strip comment lines
        QRY=`echo $QRY2 | sed 's/^\?[^ ]* *//'`  # remove the params
        DBPARM=`echo $QRY2 | sed -r 's/(\?[^ ]*)?( ?.*)/\1/'` # keep just the db
        #echo "DB='$DBPARM'" >> $LOG   # ###
        #echo "Q='$QRY'" >> $LOG       # ###
        #echo "C-DB='$CONNECTOR$DBPARM'" >> $LOG # ###
        if [ ! -z "$QRY" ]
        then
          zoomsh "connect localhost:9070" "set databaseName $CONNECTOR$DBPARM" \
                  "set count 2" "search $QRY" "quit" >>$LOG
          test $? -ne 0 && RET=1
        fi
      done < $QRYFILE
    fi
    I=$DIR/$CNAME.input
    if test -f $I; then
        echo "===== $I ======" >> $LOG
	echo "connect localhost:9070" >input.tmp
	echo "set databaseName $CONNECTOR$DBPARM" >>input.tmp
	cat $I >>input.tmp
	echo "quit" >>input.tmp
	zoomsh < input.tmp | sed 's/ZOOM>//g' >>$LOG
        test $? -ne 0 && RET=1
	rm -f input.tmp
    fi
    if $checkresult; then
        if test -f $DIR/$CNAME.out; then
	    diff $diff_opt $DIR/$CNAME.out $LOG
	    if test $? -ne 0; then
	        echo "  $CNAME: differ (MP)"
                GRET=1
	    else
	        echo "  $CNAME: OK (MP)"
	    fi
        else
            echo "   $CNAME: Making for the first time"
            cp $LOG $DIR/$CNAME.out
        fi
    else
        echo "   $CNAME: RET=$RET"
    fi
    if [ "$GRET" = 1 -a "$REGRESSION_FATAL" = "true" ]
    then
        echo Exiting at first error
        exit $GRET
    fi
done # connector loop

exit $GRET
